from abusers.camegame import ehh
from abusers.camegame import isEhhed
from abusers.camegame import isJuljung
from abusers.camegame import stopEhh
from abusers.camegame import touchLoop
from abusers.camegame import whereTouch
from abusers.camegame import attackOldPerson
from abusers.camegame import setOldPersonCount
from abusers.camegame import mineBitcoin
